EXPORTS
	TextPredefEntitiesNotEscaped__14CXmlPullParserR6TPtrC8 @ 1 NONAME R3UNUSED ; CXmlPullParser::TextPredefEntitiesNotEscaped(TPtrC8 &)
	AddCdataSectL__10CXmlWriterRC6TDesC8 @ 2 NONAME R3UNUSED ; CXmlWriter::AddCdataSectL(TDesC8 const &)
	AddEndTagL__10CXmlWriterRC6TDesC8 @ 3 NONAME R3UNUSED ; CXmlWriter::AddEndTagL(TDesC8 const &)
	AddPrologL__10CXmlWriter @ 4 NONAME R3UNUSED ; CXmlWriter::AddPrologL(void)
	AddPrologL__10CXmlWriterRC6TDesC8 @ 5 NONAME R3UNUSED ; CXmlWriter::AddPrologL(TDesC8 const &)
	AddStartTagL__10CXmlWriterRC6TDesC8 @ 6 NONAME R3UNUSED ; CXmlWriter::AddStartTagL(TDesC8 const &)
	AddTextL__10CXmlWriterRC6TDesC8 @ 7 NONAME R3UNUSED ; CXmlWriter::AddTextL(TDesC8 const &)
	AttributeCount__14CXmlPullParserRi @ 8 NONAME R3UNUSED ; CXmlPullParser::AttributeCount(int &)
	AttributeName__14CXmlPullParseriR6TPtrC8 @ 9 NONAME R3UNUSED ; CXmlPullParser::AttributeName(int, TPtrC8 &)
	AttributeValueL__14CXmlPullParserRC6TDesC8R6TPtrC8 @ 10 NONAME R3UNUSED ; CXmlPullParser::AttributeValueL(TDesC8 const &, TPtrC8 &)
	AttributeValueL__14CXmlPullParseriR6TPtrC8 @ 11 NONAME R3UNUSED ; CXmlPullParser::AttributeValueL(int, TPtrC8 &)
	AttributeValuePredefEntitiesNotEscaped__14CXmlPullParserRC6TDesC8R6TPtrC8 @ 12 NONAME R3UNUSED ; CXmlPullParser::AttributeValuePredefEntitiesNotEscaped(TDesC8 const &, TPtrC8 &)
	AttributeValuePredefEntitiesNotEscaped__14CXmlPullParseriR6TPtrC8 @ 13 NONAME R3UNUSED ; CXmlPullParser::AttributeValuePredefEntitiesNotEscaped(int, TPtrC8 &)
	CloseStartTagL__10CXmlWriteri @ 14 NONAME R3UNUSED ; CXmlWriter::CloseStartTagL(int)
	CurrentElementPos__14CXmlPullParser @ 15 NONAME R3UNUSED ; CXmlPullParser::CurrentElementPos(void)
	Depth__14CXmlPullParserRi @ 16 NONAME R3UNUSED ; CXmlPullParser::Depth(int &)
	DocPart__10CXmlWriterii @ 17 NONAME R3UNUSED ; CXmlWriter::DocPart(int, int)
	DocPart__14CXmlPullParserii @ 18 NONAME R3UNUSED ; CXmlPullParser::DocPart(int, int)
	InsertTextL__10CXmlWriteriRC6TDesC8 @ 19 NONAME R3UNUSED ; CXmlWriter::InsertTextL(int, TDesC8 const &)
	IsEmptyElement__14CXmlPullParserRi @ 20 NONAME R3UNUSED ; CXmlPullParser::IsEmptyElement(int &)
	Length__10CXmlWriter @ 21 NONAME R3UNUSED ; CXmlWriter::Length(void)
	Length__14CXmlPullParser @ 22 NONAME R3UNUSED ; CXmlPullParser::Length(void)
	Name__14CXmlPullParserR6TPtrC8 @ 23 NONAME R3UNUSED ; CXmlPullParser::Name(TPtrC8 &)
	NewLC__10CXmlWriter @ 24 NONAME R3UNUSED ; CXmlWriter::NewLC(void)
	NewLC__14CXmlPullParserR15CDesC8ArrayFlat @ 25 NONAME R3UNUSED ; CXmlPullParser::NewLC(CDesC8ArrayFlat &)
	NewL__10CXmlWriter @ 26 NONAME R3UNUSED ; CXmlWriter::NewL(void)
	NewL__14CXmlPullParserR15CDesC8ArrayFlat @ 27 NONAME R3UNUSED ; CXmlPullParser::NewL(CDesC8ArrayFlat &)
	NextL__14CXmlPullParser @ 28 NONAME R3UNUSED ; CXmlPullParser::NextL(void)
	OpenStartTagL__10CXmlWriterRC6TDesC8 @ 29 NONAME R3UNUSED ; CXmlWriter::OpenStartTagL(TDesC8 const &)
	PathL__14CXmlPullParserR6TPtrC8 @ 30 NONAME R3UNUSED ; CXmlPullParser::PathL(TPtrC8 &)
	Pos__14CXmlPullParser @ 31 NONAME R3UNUSED ; CXmlPullParser::Pos(void)
	Reset__10CXmlWriter @ 32 NONAME R3UNUSED ; CXmlWriter::Reset(void)
	SetInput__14CXmlPullParserRC6TDesC8 @ 33 NONAME R3UNUSED ; CXmlPullParser::SetInput(TDesC8 const &)
	State__14CXmlPullParser @ 34 NONAME R3UNUSED ; CXmlPullParser::State(void)
	TextL__14CXmlPullParserR6TPtrC8 @ 35 NONAME R3UNUSED ; CXmlPullParser::TextL(TPtrC8 &)
	AddAttributeL__10CXmlWriterRC6TDesC8T1 @ 36 NONAME R3UNUSED ; CXmlWriter::AddAttributeL(TDesC8 const &, TDesC8 const &)
	AddXmlTextL__10CXmlWriterRC6TDesC8 @ 37 NONAME R3UNUSED ; CXmlWriter::AddXmlTextL(TDesC8 const &)
	InsertXmlTextL__10CXmlWriteriRC6TDesC8 @ 38 NONAME R3UNUSED ; CXmlWriter::InsertXmlTextL(int, TDesC8 const &)

